==> root-debug-6.36.04-5-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/io/mpi/G__RMPI.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__RMPI
#define R__NO_DEPRECATION

/*******************************************************************/
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TMPIClientInfo.h"
#include "TMPIFile.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void *new_TMPIClientInfo(void *p = nullptr);
   static void *newArray_TMPIClientInfo(Long_t size, void *p);
   static void delete_TMPIClientInfo(void *p);
   static void deleteArray_TMPIClientInfo(void *p);
   static void destruct_TMPIClientInfo(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TMPIClientInfo*)
   {
      ::TMPIClientInfo *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TMPIClientInfo >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TMPIClientInfo", ::TMPIClientInfo::Class_Version(), "TMPIClientInfo.h", 18,
                  typeid(::TMPIClientInfo), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TMPIClientInfo::Dictionary, isa_proxy, 4,
                  sizeof(::TMPIClientInfo) );
      instance.SetNew(&new_TMPIClientInfo);
      instance.SetNewArray(&newArray_TMPIClientInfo);
      instance.SetDelete(&delete_TMPIClientInfo);
      instance.SetDeleteArray(&deleteArray_TMPIClientInfo);
      instance.SetDestructor(&destruct_TMPIClientInfo);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TMPIClientInfo*)
   {
      return GenerateInitInstanceLocal(static_cast<::TMPIClientInfo*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TMPIClientInfo*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void delete_TMPIFile(void *p);
   static void deleteArray_TMPIFile(void *p);
   static void destruct_TMPIFile(void *p);
   static void reset_TMPIFile(void *obj, TFileMergeInfo *info);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TMPIFile*)
   {
      ::TMPIFile *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TMPIFile >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TMPIFile", ::TMPIFile::Class_Version(), "TMPIFile.h", 40,
                  typeid(::TMPIFile), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TMPIFile::Dictionary, isa_proxy, 4,
                  sizeof(::TMPIFile) );
      instance.SetDelete(&delete_TMPIFile);
      instance.SetDeleteArray(&deleteArray_TMPIFile);
      instance.SetDestructor(&destruct_TMPIFile);
      instance.SetResetAfterMerge(&reset_TMPIFile);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TMPIFile*)
   {
      return GenerateInitInstanceLocal(static_cast<::TMPIFile*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TMPIFile*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TMPIClientInfo::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TMPIClientInfo::Class_Name()
{
   return "TMPIClientInfo";
}

//______________________________________________________________________________
const char *TMPIClientInfo::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TMPIClientInfo::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TMPIClientInfo::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TMPIClientInfo::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TMPIFile::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TMPIFile::Class_Name()
{
   return "TMPIFile";
}

//______________________________________________________________________________
const char *TMPIFile::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TMPIFile::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TMPIFile::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TMPIFile::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TMPIClientInfo::Streamer(TBuffer &R__b)
{
   // Stream an object of class TMPIClientInfo.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TMPIClientInfo::Class(),this);
   } else {
      R__b.WriteClassBuffer(TMPIClientInfo::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TMPIClientInfo(void *p) {
      return  p ? new(p) ::TMPIClientInfo : new ::TMPIClientInfo;
   }
   static void *newArray_TMPIClientInfo(Long_t nElements, void *p) {
      return p ? new(p) ::TMPIClientInfo[nElements] : new ::TMPIClientInfo[nElements];
   }
   // Wrapper around operator delete
   static void delete_TMPIClientInfo(void *p) {
      delete (static_cast<::TMPIClientInfo*>(p));
   }
   static void deleteArray_TMPIClientInfo(void *p) {
      delete [] (static_cast<::TMPIClientInfo*>(p));
   }
   static void destruct_TMPIClientInfo(void *p) {
      typedef ::TMPIClientInfo current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TMPIClientInfo

//______________________________________________________________________________
void TMPIFile::Streamer(TBuffer &R__b)
{
   // Stream an object of class TMPIFile.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TMPIFile::Class(),this);
   } else {
      R__b.WriteClassBuffer(TMPIFile::Class(),this);
   }
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TMPIFile(void *p) {
      delete (static_cast<::TMPIFile*>(p));
   }
   static void deleteArray_TMPIFile(void *p) {
      delete [] (static_cast<::TMPIFile*>(p));
   }
   static void destruct_TMPIFile(void *p) {
      typedef ::TMPIFile current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
   // Wrapper around the Reset function.
   static void reset_TMPIFile(void *obj,TFileMergeInfo *info) {
      ((::TMPIFile*)obj)->ResetAfterMerge(info);
   }
} // end of namespace ROOT for class ::TMPIFile

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libRMPI() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libRMPI) = RecordReadRules_libRMPI();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libRMPI));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libRMPI_Impl() {
    static const char* headers[] = {
"TMPIClientInfo.h",
"TMPIFile.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/usr/include",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libRMPI dictionary forward declarations' payload"
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
class __attribute__((annotate("$clingAutoload$TMPIClientInfo.h")))  TMPIClientInfo;
class __attribute__((annotate("$clingAutoload$TMPIFile.h")))  TMPIFile;
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libRMPI dictionary payload"


#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "TMPIClientInfo.h"
#include "TMPIFile.h"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
"TMPIClientInfo", payloadCode, "@",
"TMPIFile", payloadCode, "@",
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libRMPI",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libRMPI_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libRMPI_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libRMPI() {
  TriggerDictionaryInitialization_libRMPI_Impl();
}

==> root-debug-6.38.00-4-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/io/mpi/G__RMPI.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__RMPI
#define R__NO_DEPRECATION

/*******************************************************************/
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TMPIClientInfo.h"
#include "TMPIFile.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void *new_TMPIClientInfo(void *p = nullptr);
   static void *newArray_TMPIClientInfo(Long_t size, void *p);
   static void delete_TMPIClientInfo(void *p);
   static void deleteArray_TMPIClientInfo(void *p);
   static void destruct_TMPIClientInfo(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TMPIClientInfo*)
   {
      ::TMPIClientInfo *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TMPIClientInfo >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TMPIClientInfo", ::TMPIClientInfo::Class_Version(), "TMPIClientInfo.h", 18,
                  typeid(::TMPIClientInfo), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TMPIClientInfo::Dictionary, isa_proxy, 4,
                  sizeof(::TMPIClientInfo) );
      instance.SetNew(&new_TMPIClientInfo);
      instance.SetNewArray(&newArray_TMPIClientInfo);
      instance.SetDelete(&delete_TMPIClientInfo);
      instance.SetDeleteArray(&deleteArray_TMPIClientInfo);
      instance.SetDestructor(&destruct_TMPIClientInfo);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TMPIClientInfo*)
   {
      return GenerateInitInstanceLocal(static_cast<::TMPIClientInfo*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TMPIClientInfo*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void delete_TMPIFile(void *p);
   static void deleteArray_TMPIFile(void *p);
   static void destruct_TMPIFile(void *p);
   static void reset_TMPIFile(void *obj, TFileMergeInfo *info);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TMPIFile*)
   {
      ::TMPIFile *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TMPIFile >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TMPIFile", ::TMPIFile::Class_Version(), "TMPIFile.h", 40,
                  typeid(::TMPIFile), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TMPIFile::Dictionary, isa_proxy, 4,
                  sizeof(::TMPIFile) );
      instance.SetDelete(&delete_TMPIFile);
      instance.SetDeleteArray(&deleteArray_TMPIFile);
      instance.SetDestructor(&destruct_TMPIFile);
      instance.SetResetAfterMerge(&reset_TMPIFile);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TMPIFile*)
   {
      return GenerateInitInstanceLocal(static_cast<::TMPIFile*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TMPIFile*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TMPIClientInfo::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TMPIClientInfo::Class_Name()
{
   return "TMPIClientInfo";
}

//______________________________________________________________________________
const char *TMPIClientInfo::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TMPIClientInfo::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TMPIClientInfo::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TMPIClientInfo::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIClientInfo*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TMPIFile::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TMPIFile::Class_Name()
{
   return "TMPIFile";
}

//______________________________________________________________________________
const char *TMPIFile::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TMPIFile::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TMPIFile::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TMPIFile::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TMPIFile*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TMPIClientInfo::Streamer(TBuffer &R__b)
{
   // Stream an object of class TMPIClientInfo.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TMPIClientInfo::Class(),this);
   } else {
      R__b.WriteClassBuffer(TMPIClientInfo::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TMPIClientInfo(void *p) {
      return  p ? new(p) ::TMPIClientInfo : new ::TMPIClientInfo;
   }
   static void *newArray_TMPIClientInfo(Long_t nElements, void *p) {
      return p ? new(p) ::TMPIClientInfo[nElements] : new ::TMPIClientInfo[nElements];
   }
   // Wrapper around operator delete
   static void delete_TMPIClientInfo(void *p) {
      delete (static_cast<::TMPIClientInfo*>(p));
   }
   static void deleteArray_TMPIClientInfo(void *p) {
      delete [] (static_cast<::TMPIClientInfo*>(p));
   }
   static void destruct_TMPIClientInfo(void *p) {
      typedef ::TMPIClientInfo current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TMPIClientInfo

//______________________________________________________________________________
void TMPIFile::Streamer(TBuffer &R__b)
{
   // Stream an object of class TMPIFile.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TMPIFile::Class(),this);
   } else {
      R__b.WriteClassBuffer(TMPIFile::Class(),this);
   }
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TMPIFile(void *p) {
      delete (static_cast<::TMPIFile*>(p));
   }
   static void deleteArray_TMPIFile(void *p) {
      delete [] (static_cast<::TMPIFile*>(p));
   }
   static void destruct_TMPIFile(void *p) {
      typedef ::TMPIFile current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
   // Wrapper around the Reset function.
   static void reset_TMPIFile(void *obj,TFileMergeInfo *info) {
      ((::TMPIFile*)obj)->ResetAfterMerge(info);
   }
} // end of namespace ROOT for class ::TMPIFile

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libRMPI() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libRMPI) = RecordReadRules_libRMPI();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libRMPI));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libRMPI_Impl() {
    static const char* headers[] = {
"TMPIClientInfo.h",
"TMPIFile.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libRMPI dictionary forward declarations' payload"

#pragma diagnostic push
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
class  __attribute__((annotate("$clingAutoload$TMPIClientInfo.h")))  TMPIClientInfo;
class  __attribute__((annotate("$clingAutoload$TMPIFile.h")))  TMPIFile;
#pragma diagnostic pop
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libRMPI dictionary payload"

#ifndef R__DUMMY_CXX_STANDARD_17
  #define R__DUMMY_CXX_STANDARD_17 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "TMPIClientInfo.h"
#include "TMPIFile.h"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
"TMPIClientInfo", payloadCode, "@",
"TMPIFile", payloadCode, "@",
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libRMPI",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libRMPI_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libRMPI_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libRMPI() {
  TriggerDictionaryInitialization_libRMPI_Impl();
}
